/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2020 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef CONFIGDLG_H
#define CONFIGDLG_H

#include <QColorDialog>

#include "settings.h"
#include "kemboss.h"
#include "ui_configDlg.h"

class configDlg : public QDialog, private Ui::ConfigDialog
{
    Q_OBJECT

public:
    configDlg(kemboss *parent = nullptr, kembossSettings *fksettings = nullptr);
    // Constructor. The parent kemboss window and the kembossSettings objects are stored in the private variables mainKembossWindow and ksettings

private slots:
    void accept();
    // Check the settings, save them and closes the dialog
    void helpRequested();
    // Shows help dialog
    void fontChanged() { fontHasChanged = true; }
    void embassyChanged() { embassyHasChanged = true; }
    void remoteServerChanged() { remoteServerHasChanged = true; }
    void on_StyleComboBox_activated(const QString &text);
    void on_KembossDataPushButton_clicked() { setExistingDir(tr("Select kemboss data directory"), KembossDataLineEdit); }
    void on_KembossDefaultSettingsPushButton_clicked() { setExistingDir(tr("Select kemboss default settings directory"), KembossDefaultSettingsLineEdit); }
    void on_EmbossBinPushButton_clicked() { setExistingDir(tr("Select EMBOSS binaries directory"), EmbossBinLineEdit); }
    void on_EmbossHelpPushButton_clicked() { setExistingDir(tr("Select EMBOSS helpfiles directory"), EmbossHelpLineEdit); }
    void on_EmbossDataPushButton_clicked() { setExistingDir(tr("Select EMBOSS data directory"), EmbossDataLineEdit); }
    void on_BasicAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->basic_aa.foreground().color(), this); ksettings->basic_aa.setForeground(color); BasicAAPushButton->setPalette(QPalette(color)); }
    void on_CysteinPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->cystein.foreground().color(), this); ksettings->cystein.setForeground(color); CysteinPushButton->setPalette(QPalette(color)); }
    void on_ApolarAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->apolar_aa.foreground().color(), this); ksettings->apolar_aa.setForeground(color); ApolarAAPushButton->setPalette(QPalette(color)); }
    void on_PolarAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->polar_aa.foreground().color(), this); ksettings->polar_aa.setForeground(color); PolarAAPushButton->setPalette(QPalette(color)); }
    void on_AcidicAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->acidic_aa.foreground().color(), this); ksettings->acidic_aa.setForeground(color); AcidicAAPushButton->setPalette(QPalette(color)); }
    void on_DibasicAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->dibasic_aa.foreground().color(), this); ksettings->dibasic_aa.setForeground(color); DibasicAAPushButton->setPalette(QPalette(color)); }
    void on_ANucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->a_nuc.foreground().color(), this); ksettings->a_nuc.setForeground(color); ANucPushButton->setPalette(QPalette(color)); }
    void on_TNucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->t_nuc.foreground().color(), this); ksettings->t_nuc.setForeground(color); TNucPushButton->setPalette(QPalette(color)); }
    void on_GNucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->g_nuc.foreground().color(), this); ksettings->g_nuc.setForeground(color); GNucPushButton->setPalette(QPalette(color)); }
    void on_CNucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->c_nuc.foreground().color(), this); ksettings->c_nuc.setForeground(color); CNucPushButton->setPalette(QPalette(color)); }
    void on_OnlineDocCheckBox_stateChanged(int state);
    void on_LocalEmbossInstallation_clicked(bool checked) { RemoteEmbossInstallation->setChecked(!checked); }
    void on_RemoteEmbossInstallation_clicked(bool checked) { LocalEmbossInstallation->setChecked(!checked); }

private:
    void readSettings();
    // Reads the settings of the configuration dialog (position on screen, size, etc. Does not load the kemboss settings
    void writeSettings();
    // Writes the settings of the configuration dialog (position on screen, size, etc. Does not save the kemboss settings
    void setExistingDir(const QString &dlgMsg, QLineEdit *lineEdit);
    void setOpenFile(const QString &dlgMsg, QLineEdit *lineEdit);
    void setSaveFile(const QString &dlgMsg, QLineEdit *lineEdit);
    bool fontHasChanged;
    bool embassyHasChanged;
    bool remoteServerHasChanged;
    kemboss *mainKembossWindow;
    kembossSettings *ksettings;
};

#endif
