/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2020 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/
#ifndef KEMBOSSWINDOW_H
#define KEMBOSSWINDOW_H

#include <QMainWindow>
#include <QGraphicsView>
#include <QDesktopServices>
#include <QFileInfo>
#include <QToolBar>
#include <QAction>
#include <QUrl>
#include <QPointer>

class kembossWindow : public QMainWindow
// kembossWindow is the abstract base class of the kemboss main window and the class kprogramWindow, which is the abstract base class of all program windows
{
   Q_OBJECT

public:
   kembossWindow(QMainWindow *parent = nullptr);
   virtual ~kembossWindow() {}
   QString curFile;
   void updateRecentFileActions();
   QPointer<kembossWindow> kembossParent;
   QPointer<QGraphicsView> kpwOutputGraphicsView;

protected:
   void readSettings();
   void writeSettings();
   void createActions();
   void createRecentFiles();
   void assistant(const QString &page);
   QPointer<QMenu> recentSettingsMenu;
   QAction *reportBugAct;
   QAction *aboutAct;
   enum { MaxRecentFiles = 4 };
   QAction *recentFileActs[MaxRecentFiles];
   QString strippedName(const QString &fullFileName) { return QFileInfo(fullFileName).fileName(); }
   QToolBar *fileToolBar;
   QToolBar *editToolBar;
   QToolBar *viewToolBar;
   QToolBar *graphToolBar;
   QToolBar *runToolBar;
   QToolBar *helpToolBar;
   QAction *viewFileToolbarAct;
   QAction *viewEditToolbarAct;
   QAction *viewViewToolbarAct;
   QAction *viewGraphToolbarAct;
   QAction *viewRunToolbarAct;
   QAction *viewHelpToolbarAct;

   int seqFormatInput;
   int seqFormatOutput;

private:
   virtual bool loadSettings(const QString &fileName) = 0;
   virtual bool saveSettings(const QString &fileName) = 0;
   virtual bool maybeSave() = 0;
   virtual void setCurrentFile(const QString &fileName) = 0;
   void showFileToolbar(const bool &show) { fileToolBar->setVisible(show); viewFileToolbarAct->setChecked(show); }
   void showEditToolbar(const bool &show) { editToolBar->setVisible(show); viewEditToolbarAct->setChecked(show); }
   void showViewToolbar(const bool &show) { viewToolBar->setVisible(show); viewViewToolbarAct->setChecked(show); }
   void showGraphToolbar(const bool &show) { graphToolBar->setVisible(show); viewGraphToolbarAct->setChecked(show); }
   void showRunToolbar(const bool &show) { runToolBar->setVisible(show); viewRunToolbarAct->setChecked(show); }
   void showHelpToolbar(const bool &show) { helpToolBar->setVisible(show); viewHelpToolbarAct->setChecked(show); }

protected slots:
   bool save();
   bool saveAs();
   void open();

private slots:
   void openRecentFile();
   void aboutKemboss();
   void viewFileToolbar() { showFileToolbar(!fileToolBar->isVisible()); }
   void viewEditToolbar() { showEditToolbar(!editToolBar->isVisible()); }
   void viewViewToolbar() { showViewToolbar(!viewToolBar->isVisible()); }
   void viewGraphToolbar() { showGraphToolbar(!graphToolBar->isVisible()); }
   void viewRunToolbar() { showRunToolbar(!runToolBar->isVisible()); }
   void viewHelpToolbar() { showHelpToolbar(!helpToolBar->isVisible()); }
   void reportBug() { QDesktopServices::openUrl (QUrl("mailto:mail@kemboss.org?subject=Bug in "+objectName())); }
};

#endif
