/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2019 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#include "programWindows.h"

#include <QMessageBox>

void kabiview::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "graph");
}

void kalignment::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   AlternativesLabel->setEnabled(false);
   AlternativesSpinBox->setEnabled(false);
   AlignmentWidthSpinBox->setEnabled(false);
   AlignmentWidthLabel->setEnabled(false);
   WordLengthSpinBox->setEnabled(false);
   WordLengthLabel->setEnabled(false);
   EndweightCheckBox->setEnabled(false);
   EndGapOpenPenaltyLabel->setEnabled(false);
   EndGapOpenPenaltyDoubleSpinBox->setEnabled(false);
   EndGapExtensionPenaltyLabel->setEnabled(false);
   EndGapExtensionPenaltyDoubleSpinBox->setEnabled(false);
   MinimumScoreLabel->setEnabled(false);
   MinimumScoreDoubleSpinBox->setEnabled(false);
   ErrorfileLabel->setEnabled(false);
   ErrorfileLineEdit->setEnabled(false);
   ErrorfileSaveAsPushButton->setEnabled(false);
   BriefIdentityAndSimilarityCheckBox->setEnabled(false);
   if (text == "water") {
      BriefIdentityAndSimilarityCheckBox->setEnabled(true);
      PenaltiesStackedWidget->setCurrentIndex(0);
   } else if (text == "needle" || text == "needleall") {
      BriefIdentityAndSimilarityCheckBox->setEnabled(true);
      PenaltiesStackedWidget->setCurrentIndex(0);
      EndweightCheckBox->setEnabled(true);
      EndGapOpenPenaltyLabel->setEnabled(true);
      EndGapOpenPenaltyDoubleSpinBox->setEnabled(true);
      EndGapExtensionPenaltyLabel->setEnabled(true);
      EndGapExtensionPenaltyDoubleSpinBox->setEnabled(true);
      if (text == "needleall") {
         MinimumScoreLabel->setEnabled(true);
         MinimumScoreDoubleSpinBox->setEnabled(true);
         ErrorfileLabel->setEnabled(true);
         ErrorfileLineEdit->setEnabled(true);
         ErrorfileSaveAsPushButton->setEnabled(true);
      }
   } else if (text == "matcher") {
      AlternativesLabel->setEnabled(true);
      AlternativesSpinBox->setEnabled(true);
      PenaltiesStackedWidget->setCurrentIndex(1);
   } else if (text == "supermatcher") {
      AlignmentWidthSpinBox->setEnabled(true);
      AlignmentWidthLabel->setEnabled(true);
      WordLengthSpinBox->setEnabled(true);
      WordLengthLabel->setEnabled(true);
      PenaltiesStackedWidget->setCurrentIndex(0);
   } else if (text == "stretcher") {
      PenaltiesStackedWidget->setCurrentIndex(1);
   }
   runEmbossApp->setEmbossApp(text);
}

void kalignment::beforeRunningProgram()
{
   QString num;
   if (PenaltiesStackedWidget->currentIndex() == 0) {
      num.setNum(GapOpenPenaltyDoubleSpinBox->value());
      runEmbossApp->programConfiguration.append("-gapopen="+num);
      num.setNum(GapExtensionPenaltyDoubleSpinBox->value());
      runEmbossApp->programConfiguration.append("-gapextend="+num);
   } else {
      if (GapOpenPenaltySpinBox->value() != 0) {
         num.setNum(GapOpenPenaltyDoubleSpinBox->value());
         runEmbossApp->programConfiguration.append("-gapopen="+num);
      }
      if (GapExtensionPenaltySpinBox->value() != 0) {
         num.setNum(GapExtensionPenaltyDoubleSpinBox->value());
         runEmbossApp->programConfiguration.append("-gapextend="+num);
      }
   }
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossOutputFile(ErrorfileLineEdit->text());
}

void kanalyzeseq::setEmbossApp(const QString &appName)
{
   SeqcountGroupBox->setChecked(false);
   WordCountGroupBox->setChecked(false);
   SeqmatchallGroupBox->setChecked(false);
   RegularExpressionSearchGroupBox->setChecked(false);
   PatternSearchGroupBox->setChecked(false);
   ChipsGroupBox->setChecked(false);
   MarscanGroupBox->setChecked(false);
   GeeCeeGroupBox->setChecked(false);
   GarnierGroupBox->setChecked(false);
   CuspGroupBox->setChecked(false);
   CaiGroupBox->setChecked(false);
   PscanGroupBox->setChecked(false);
   PepstatsGroupBox->setChecked(false);
   if (appName == "wordcount") {
      WordCountGroupBox->setChecked(true);
      qualifierNum = "";
   } else if (appName == "seqcount") {
      SeqcountGroupBox->setChecked(true);
      qualifierNum = "";
   } else if (appName == "seqmatchall") {
      SeqmatchallGroupBox->setChecked(true);
      qualifierNum = "0";
   } else if (appName == "dreg") {
      RegularExpressionSearchGroupBox->setChecked(true);
      InputComboBox->setCurrentIndex(0);
   } else if (appName == "preg") {
      MotifIsInPROSITEFormatCheckBox->setChecked(false);
      RegularExpressionSearchGroupBox->setChecked(true);
      InputComboBox->setCurrentIndex(1);
   } else if (appName == "patmatdb") {
      MotifIsInPROSITEFormatCheckBox->setChecked(true);
      RegularExpressionSearchGroupBox->setChecked(true);
      InputComboBox->setCurrentIndex(1);
   } else if (appName == "fuzznuc") {
      PatternSearchGroupBox->setChecked(true);
      InputComboBox2->setCurrentIndex(0);
   } else if (appName == "fuzzpro") {
      PatternSearchGroupBox->setChecked(true);
      InputComboBox2->setCurrentIndex(1);
   } else if (appName == "fuzztran") {
      PatternSearchGroupBox->setChecked(true);
      InputComboBox2->setCurrentIndex(2);
   } else if (appName == "marscan") {
      MarscanGroupBox->setChecked(true);
      qualifierNum = "2";
   } else if (appName == "geecee") {
      GeeCeeGroupBox->setChecked(true);
      qualifierNum = "";
   } else if (appName == "garnier") {
      GarnierGroupBox->setChecked(true);
      qualifierNum = "2";   
   } else if (appName == "chips") {
      ChipsGroupBox->setChecked(true);
   } else if (appName == "cusp") {
      CuspGroupBox->setChecked(true);
      qualifierNum = "";
   } else if (appName == "cai") {
      CaiGroupBox->setChecked(true);
   } else if (appName == "pscan") {
      PscanGroupBox->setChecked(true);
      qualifierNum = "";
   } else if (appName == "pepstats") {
      PepstatsGroupBox->setChecked(true);
      qualifierNum = "";
   }
   if (appName == "chips" || appName == "cai") {
      InputFileLineEdit->setToolTip("seqall");
      qualifierNum = "";
   } else {
      InputFileLineEdit->setToolTip("sequence");
   }
   runEmbossApp->setEmbossApp(appName);
}

void kanalyzeseq::on_InputComboBox_currentIndexChanged(int index)
{
   qualifierNum = "3";
   if (index == 0) {
      MotifIsInPROSITEFormatCheckBox->setEnabled(false);
      RegularExpressionLineEdit->setToolTip("pattern");
      runEmbossApp->setEmbossApp("dreg");
   } else {
      MotifIsInPROSITEFormatCheckBox->setEnabled(true);
      on_MotifIsInPROSITEFormatCheckBox_stateChanged(MotifIsInPROSITEFormatCheckBox->checkState());
   }
}

void kanalyzeseq::on_MotifIsInPROSITEFormatCheckBox_stateChanged(int state)
{
   if (state == Qt::Checked) {
      RegularExpressionLineEdit->setToolTip("motif");
      runEmbossApp->setEmbossApp("patmatdb");
   } else {
      RegularExpressionLineEdit->setToolTip("pattern");
      runEmbossApp->setEmbossApp("preg");
   }
}

void kanalyzeseq::on_InputComboBox2_currentIndexChanged(int index)
{
   qualifierNum = "2";
   switch (index) {
    case 0: runEmbossApp->setEmbossApp("fuzznuc");
            FramesToTranslateLabel->setEnabled(false);
            FramesComboBox->setEnabled(false);
            GeneticCodeLabel->setEnabled(false);
            GeneticCodeComboBox->setEnabled(false);
            SearchComplementaryStrandCheckBox->setEnabled(true);
            break;
    case 1: runEmbossApp->setEmbossApp("fuzzpro");
            FramesToTranslateLabel->setEnabled(false);
            FramesComboBox->setEnabled(false);
            GeneticCodeLabel->setEnabled(false);
            GeneticCodeComboBox->setEnabled(false);
            SearchComplementaryStrandCheckBox->setEnabled(false);
            break;
    case 2: runEmbossApp->setEmbossApp("fuzztran");
            FramesToTranslateLabel->setEnabled(true);
            FramesComboBox->setEnabled(true);
            GeneticCodeLabel->setEnabled(true);
            GeneticCodeComboBox->setEnabled(true);
            SearchComplementaryStrandCheckBox->setEnabled(false);
            break;
   }
}

void kanalyzeseq::on_OutfileAssociatedQualifiersPushButton2_clicked()
{
   if (qualifierNum == "0") {
      openAAQForm("2");
   } else if (qualifierNum == "2" || qualifierNum == "3") {
      openOAQForm(qualifierNum);
   } else if (qualifierNum == "")
      QMessageBox::information(this, objectName(),tr("This program doesn't support any outfile associated qualifiers."));
}

void kanalyzeseq::beforeRunningProgram()
{
   if (runEmbossApp->embossApp() == "fuzztran") {
      runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
      runEmbossApp->programConfiguration.append("-frame="+FramesComboBox->currentText().section(" ", 0, 0));
   } else if (runEmbossApp->embossApp() == "cai") {
      runEmbossApp->programConfiguration.append("-cfile="+CodonUsageFileComboBox->currentText().section(" ", 0, 0));
   } else if (runEmbossApp->embossApp() == "pepstats") {
       runEmbossApp->addEmbossInputFile(AminoAcidDataFileLineEdit->text());
       runEmbossApp->addEmbossInputFile(MolecularWeightsDataFileLineEdit->text());
   }
}

void kassembly::setEmbossApp(const QString &appName)
{
    if (appName == "infoassembly") {
        InfoassemblyGroupBox->setChecked(true);
    } else {
        InfoassemblyGroupBox->setChecked(false);
    }
    runEmbossApp->setEmbossApp(appName);
}

void kassembly::beforeRunningProgram()
{
    completeOutputFilename(GcBiasMetricsOutfileLineEdit, "GCbiasmetrics");
    completeOutputFilename(QualValuesDistOutfileLineEdit, "qualityvalues");
    runEmbossApp->addEmbossInputFile(RefsequenceLineEdit->text());
}

void kbacktranambig::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
}

void kbacktranseq::beforeRunningProgram()
{
    runEmbossApp->programConfiguration.append("-cfile="+CodonUsageTableComboBox->currentText().section(" ", 0, 0));
}

void kbanana::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "graph");
   runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void kbtwisted::beforeRunningProgram()
{
   runEmbossApp->addEmbossInputFile(AngleDataFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(EnergyDataFileLineEdit->text());
}

void kcharge::beforeRunningProgram()
{
   if (CreateGraphGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "graph");
   runEmbossApp->addEmbossInputFile(AminoAcidDataFileLineEdit->text());
}

void kchecktrans::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "feat");
   completeOutputFilename(OutputFileLineEdit3, "seq");
}

void kcodcmp::beforeRunningProgram()
{
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kcoderet::beforeRunningProgram()
{
   completeOutputFilename(CodingNucleotidesLineEdit, "seq1");
   completeOutputFilename(MessengerRNALineEdit, "seq2");
   completeOutputFilename(TranslatedProteinLineEdit, "seq3");
   completeOutputFilename(NonCodingNucleotidesLineEdit, "seq4");
}

void kcompseq::beforeRunningProgram()
{
   runEmbossApp->addEmbossInputFile(CompseqFileToCompareAgainstLineEdit->text());
}

void kcons::beforeRunningProgram()
{
   QString num;
   if (PluralityDoubleSpinBox->value()!=-1) {
      num.setNum(PluralityDoubleSpinBox->value());
      runEmbossApp->programConfiguration.append("-plurality="+num);
   }
   if (UpperCaseDoubleSpinBox->value()!=-1) {
      num.setNum(UpperCaseDoubleSpinBox->value());
      runEmbossApp->programConfiguration.append("-setcase="+num);
   }
}

void kcpgplot::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool setTo;
   if (text == "cpgplot") setTo = true; else setTo = false;
      ShowGraphGroupBox->setEnabled(setTo);
      ShiftSpinBox->setEnabled(!setTo);
      ShiftLabel->setEnabled(!setTo);
      FeatureFileLabel->setEnabled(setTo);
      FeatureFileLineEdit->setEnabled(setTo);
      SaveFeatureFileAsPushButton->setEnabled(setTo);
      OutfeatAssociatedQualifiersPushButton->setEnabled(setTo);
      GraphLabel->setEnabled(setTo);
      GraphLineEdit->setEnabled(setTo);
      SaveGraphAsPushButton->setEnabled(setTo);
      GraphAssociatedQualifiersPushButton->setEnabled(setTo);
   runEmbossApp->setEmbossApp(text);
}

void kcpgplot::beforeRunningProgram()
{
   completeOutputFilename(FeatureFileLineEdit, "feat");
   completeOutputFilename(GraphLineEdit, "graph");
}

void kcpgreport::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool setTo;
   if (text == "cpgreport") setTo = true; else setTo = false;
      FeatureFileLabel->setEnabled(setTo);
      FeatureFileLineEdit->setEnabled(setTo);
      SaveFeatureFileAsPushButton->setEnabled(setTo);
      OutfeatAssociatedQualifiersPushButton->setEnabled(setTo);
   runEmbossApp->setEmbossApp(text);
}

void kcpgreport::beforeRunningProgram()
{
   if (ProgramComboBox->currentText() == "cpgreport") completeOutputFilename(FeatureFileLineEdit, "feat");
}

void kdan::beforeRunningProgram()
{
   if (GraphGroupBox->isChecked()) runEmbossApp->programConfiguration.append("-goutfile="+OutputFileLineEdit->text());
}

void kdensity::beforeRunningProgram()
{
   if (QuadRadioButton->isChecked()) {
      runEmbossApp->programConfiguration.append("-quad");
      completeOutputFilename(GraphLineEdit, "graph");
   } else if (DualRadioButton->isChecked()) {
      runEmbossApp->programConfiguration.append("-dual");
      completeOutputFilename(GraphLineEdit, "graph");
   }
}

void kdiffseq::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
    completeOutputFilename(WriteFeatureTableAToLineEdit, "a.feat");
    completeOutputFilename(WriteFeatureTableBToLineEdit, "b.feat");
}

void kpepdigest::beforeRunningProgram()
{
   QString num;
   num.setNum(EnzymeOrReagentComboBox->currentIndex()+1);
   runEmbossApp->programConfiguration.append("-menu="+num);
   if (RaggingGroupBox->isChecked()) {
      num.setNum(TerminiComboBox->currentIndex()+1);
      runEmbossApp->programConfiguration.append("-termini="+num);
   }
   runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void kdistmat::beforeRunningProgram()
{
   QString num;
   num.setNum(NucleicAcidMethodComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-nucmethod="+num);
   num.setNum(ProteinMethodComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-protmethod="+num);
}

kdotplot::kdotplot(kemboss *parent, const int &program) : kprogramWindow(parent)
{
   setupUi(this);
   loadFormats("graph_types", XYGraphFormatComboBox);
   postWindowCreated();
   kpwProgramComboBox->setCurrentIndex(program);
}

void kdotplot::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool setTo;
   if (text == "dotmatcher") setTo = true; else setTo = false;
      WindowSizeLabel->setEnabled(setTo);
      WindowSizeSpinBox->setEnabled(setTo);
      ThresholdLabel->setEnabled(setTo);
      ThresholdSpinBox->setEnabled(setTo);
      SubstitutionMatrixLabel->setEnabled(setTo);
      SubstitutionMatrixComboBox->setEnabled(setTo);
   if (text == "dotmatcher" || text == "dottup") setTo = true; else setTo = false;
      XYGraphFormatLabel->setEnabled(setTo);
      XYGraphFormatComboBox->setEnabled(setTo);
      NonProportionalGraphCheckBox->setEnabled(setTo);
   if (text == "dotpath" || text == "dottup") setTo = true; else setTo = false;
      WordSizeLabel->setEnabled(setTo);
      WordSizeSpinBox->setEnabled(setTo);
      DrawBoxCheckBox->setEnabled(setTo);
   if (text == "dotpath") {
      WordSizeSpinBox->setValue(4);
      DisplayOverlappingMatchesCheckBox->setEnabled(true);
   } else DisplayOverlappingMatchesCheckBox->setEnabled(false);
   if (text == "dottup")
      WordSizeSpinBox->setValue(10);
   runEmbossApp->setEmbossApp(ProgramComboBox->currentText());
}

void kdotplot::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

kdrawmap::kdrawmap(kemboss *parent, const int &program) : kprogramWindow(parent)
{
   setupUi(this);
   loadFormats("colours", ColourOfJunctionsComboBox);
   postWindowCreated();
   kpwProgramComboBox->setCurrentIndex(program);
}

void kdrawmap::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   if (text == "cirdna") {
      MoleculesOriginOnTheCircleLabel->setEnabled(true);
      MoleculesOriginOnTheCircleDoubleSpinBox->setEnabled(true);
      JunctionsBetweenBlocksCheckBox->setEnabled(true);
      TypeOfJunctionsLabel->setEnabled(false);
      TypeOfJunctionsComboBox->setEnabled(false);
      WidthOfLeftMarginDoubleSpinBox->setEnabled(false);
      WidthOfLeftMarginLabel->setEnabled(false);
      BlockPositionComboBox->setEnabled(true);
      BlockPositionLabel->setEnabled(true);
      TickPositionLabel->setEnabled(true);
      TickPositionComboBox->setEnabled(true);
   } else if (text == "lindna") {
      MoleculesOriginOnTheCircleLabel->setEnabled(false);
      MoleculesOriginOnTheCircleDoubleSpinBox->setEnabled(false);
      JunctionsBetweenBlocksCheckBox->setEnabled(false);
      TypeOfJunctionsLabel->setEnabled(true);
      TypeOfJunctionsComboBox->setEnabled(true);
      WidthOfLeftMarginDoubleSpinBox->setEnabled(true);
      WidthOfLeftMarginLabel->setEnabled(true);
      BlockPositionComboBox->setEnabled(false);
      BlockPositionLabel->setEnabled(false);
      TickPositionLabel->setEnabled(false);
      TickPositionComboBox->setEnabled(false);
   }
   runEmbossApp->setEmbossApp(ProgramComboBox->currentText());
}

void kdrawmap::beforeRunningProgram()
{
   QString num;
   num.setNum(ColourOfJunctionsComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-intercolour="+num);
}

void kedam::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   QString app = text.section("(", 1, 1);
   app.chop(1);
   runEmbossApp->setEmbossApp(app);
   if (app == "edamdef" || app == "edamname") {
      QueryLineEdit->setToolTip("query");
      SensitiveCheckBox->setEnabled(false);
   } else {
      QueryLineEdit->setToolTip("identifier");
      SensitiveCheckBox->setEnabled(true);
   }
}

void kedam::beforeRunningProgram()
{
   QString ns = "";
   if (DataCheckBox->isChecked()) ns+="data,";
   if (EntityCheckBox->isChecked()) ns+="entity,";
   if (FormatCheckBox->isChecked()) ns+="format,";
   if (IdentifierCheckBox->isChecked()) ns+="identifier,";
   if (OperationCheckBox->isChecked()) ns+="operation,";
   if (ResourceCheckBox->isChecked()) ns+="resource,";
   if (TopicCheckBox->isChecked()) ns+="topic,";
   ns.chop(1);
   runEmbossApp->programConfiguration.append("-namespace="+ns);
}

void kedialign::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "align");
   runEmbossApp->programConfiguration.append("-nucmode="+NucleicAcidAlignmentModeComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->programConfiguration.append("-linkage="+ClusteringMethodComboBox->currentText().section(" ", 0, 0));
}

void keinverted::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "seq");
}

void kemma::beforeRunningProgram()
{
   if (KtupSpinBox->value() != -1) { runEmbossApp->programConfiguration.append("-ktup="+KtupSpinBox->text()); }
   if (GapPenaltySpinBox->value() != -1) { runEmbossApp->programConfiguration.append("-gapw="+GapPenaltySpinBox->text()); }
   if (TopDiagsSpinBox->value() != -1) { runEmbossApp->programConfiguration.append("-topdiags="+TopDiagsSpinBox->text()); }
   if (WindowSpinBox->value() != -1) { runEmbossApp->programConfiguration.append("-window="+WindowSpinBox->text()); }
   runEmbossApp->programConfiguration.append("-pwmatrix="+PASubstitutionMatrixComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-pwdnamatrix="+PADNASubstitutionMatrixComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-matrix="+MASubstitutionMatrixComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-dnamatrix="+MADNASubstitutionMatrixComboBox->currentText().left(1));
   completeOutputFilename(DendrogramFileLineEdit, "dend");
   runEmbossApp->addEmbossInputFile(OldDendrogramLineEdit->text());
   runEmbossApp->addEmbossInputFile(UserPairwiseMatrixLineEdit->text());
   runEmbossApp->addEmbossInputFile(UserMultipleAlignmentMatrixLineEdit->text());
}

void kemowse::beforeRunningProgram()
{
   QString num;
   num.setNum(EnzymeComboBox->currentIndex()+1);
   runEmbossApp->programConfiguration.append("-enzyme="+num);
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossInputFile(FrequenciesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(AADataFileLineEdit->text());
}

void kepestfind::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
    completeOutputFilename(OutputFileLineEdit2, "graph");
}

void keprimer3::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   runEmbossApp->setEmbossApp(text);
   bool boolean = false;
   if (text == "eprimer3") {
      boolean = false;
   } else if (text == "eprimer32") {
      boolean = true;
   }
   MeltingTemperatureCalculationLabel->setEnabled(boolean);
   MeltingTemperatureCalculationComboBox->setEnabled(boolean);
   SaltCorrectionFormulaLabel->setEnabled(boolean);
   SaltCorrectionFormulaComboBox->setEnabled(boolean);
}

void keprimer3::beforeRunningProgram()
{
   if (WhatToDoComboBox->isEnabled()) {
      QString num;
      num.setNum(WhatToDoComboBox->currentIndex()+1);
      runEmbossApp->programConfiguration.append("-task="+num);
   }
   if (runEmbossApp->embossApp() == "eprimer32") {
      QString num;
      num.setNum(SaltCorrectionFormulaComboBox->currentIndex());
      runEmbossApp->programConfiguration.append("-scorrection="+num);
      num.setNum(MeltingTemperatureCalculationComboBox->currentIndex());
      runEmbossApp->programConfiguration.append("-tmformula="+num);
   }
   runEmbossApp->addEmbossInputFile(MisprimingLibraryLineEdit->text());
   runEmbossApp->addEmbossInputFile(OligoMishyridizationLibraryLineEdit->text());
}

void kequicktandem::beforeRunningProgram()
{
    completeOutputFilename(OutputFileLineEdit2, "orig");
}

void kest2genome::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void ketandem::beforeRunningProgram()
{
    completeOutputFilename(OutputFileLineEdit2, "orig");
}

void kextractfeat::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-sense="+SenseComboBox->currentText().section(" ", 0, 0));
}

void kfeatmerge::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kfeatreport::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kfinddatabase::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   QString app = text.section("(", 1, 1);
   app.chop(1);
   runEmbossApp->setEmbossApp(app);
}

void kfindkm::beforeRunningProgram()
{
   if (CreateGraphGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "graph");
}

void kfreak::beforeRunningProgram()
{
   if (CreateGraphGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "graph");
}

void kget::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   runEmbossApp->setEmbossApp(text);
   bool boolean = false;
   ObsoleteCheckBox->setEnabled(false);
   SubclassesCheckBox->setEnabled(false);
   if (text == "textget") {
      boolean = false;
      InputFileLineEdit->setToolTip("text");
   } else if (text == "urlget") {
      boolean = true;
      InputFileLineEdit->setToolTip("url");
   } else if (text == "variationget") {
      boolean = false;
      InputFileLineEdit->setToolTip("variation");
   } else if (text == "refseqget") {
      boolean = false;
      InputFileLineEdit->setToolTip("refsequence");
   } else if (text == "xmlget") {
      boolean = false;
      InputFileLineEdit->setToolTip("xml");
   } else if (text == "xmltext") {
      boolean = false;
      ObsoleteCheckBox->setEnabled(true);
      SubclassesCheckBox->setEnabled(true);
      InputFileLineEdit->setToolTip("xml");
   }
   SwissCheckBox->setEnabled(boolean);
   EmblCheckBox->setEnabled(boolean);
   AccessionLabel->setEnabled(boolean);
   AccessionLineEdit->setEnabled(boolean);
   IdentifierLabel->setEnabled(boolean);
   IdentifierLineEdit->setEnabled(boolean);
}

void kgetorf::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
   QString num;
   num.setNum(OutputComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-find="+num);
}

void kgo::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
    QString app = text.section("(", 1, 1);
    app.chop(1);
    runEmbossApp->setEmbossApp(app);
}

void kgo::beforeRunningProgram()
{
    QString ns = "";
    if (ProcessCheckBox->isChecked()) ns+="biological_process,";
    if (ComponentCheckBox->isChecked()) ns+="cellular_component,";
    if (FunctionCheckBox->isChecked()) ns+="molecular_function,";
    ns.chop(1);
    runEmbossApp->programConfiguration.append("-namespace="+ns);
}

void khmoment::beforeRunningProgram()
{
   if (CreateGraphGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "graph");
}

void kiep::beforeRunningProgram()
{
   if (CreateGraphGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "graph");
}

void kinfo::on_ProgramComboBox_currentIndexChanged(int value)
{
   bool boolean;
   if (value == 0) {
      runEmbossApp->setEmbossApp("infobase");
      boolean = false;
   } else {
      boolean = true;
      runEmbossApp->setEmbossApp("inforesidue");
   }
   AAPropertiesFileLabel->setEnabled(boolean);
   AAPropertiesFileLineEdit->setEnabled(boolean);
   AAPropertiesFilePushButton->setEnabled(boolean);
   AAMolWeightLabel->setEnabled(boolean);
   AAMolWeightLineEdit->setEnabled(boolean);
   AAMolWeightPushButton->setEnabled(boolean);
}

void kinfo::beforeRunningProgram()
{
   runEmbossApp->addEmbossInputFile(AAPropertiesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(AAMolWeightLineEdit->text());
}

void kisochore::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "graph");
}

void kjaspscan::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-menu="+MatrixSetComboBox->currentText().left(1));
}

void klistor::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-operator="+LogicalOperatorComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kmakeseq::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   if (text == "Nucleic acid") {
      DataFileLineEdit->setToolTip("codonfile");
      runEmbossApp->setEmbossApp("makenucseq");
   } else if (text == "Protein") {
      DataFileLineEdit->setToolTip("pepstatsfile");
      runEmbossApp->setEmbossApp("makeprotseq");
   }
}

void kmakeseq::beforeRunningProgram()
{
  runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void kmegamerger::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "seq");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kmerger::beforeRunningProgram()
{
   completeOutputFilename(MergedSequenceLineEdit, "merged");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kmodifyseq::setEmbossApp(const QString &appName)
{
   DeleteRegionGroupBox->setChecked(false);
   SplitterGroupBox->setChecked(false);
   RemoveGapCharactersGroupBox->setChecked(false);
   PasteseqGroupBox->setChecked(false);
   ExcludeSequencesGroupBox->setChecked(false);
   ExtractseqGroupBox->setChecked(false);
   ExtractalignGroupBox->setChecked(false);
   MaskRegionGroupBox->setChecked(false);
   ReverseComplementGroupBox->setChecked(false);
   ShuffleSequenceGroupBox->setChecked(false);
   DescseqGroupBox->setChecked(false);
   BiosedGroupBox->setChecked(false);
   MaskAmbiguityCaractersNGroupBox->setChecked(false);
   MaskAmbiguityCaractersPGroupBox->setChecked(false);
   SortBySizeGroupBox->setChecked(false);

   if (appName == "cutseq") DeleteRegionGroupBox->setChecked(true);
   else if (appName == "splitter") SplitterGroupBox->setChecked(true);
   else if (appName == "degapseq") RemoveGapCharactersGroupBox->setChecked(true);
   else if (appName == "pasteseq") PasteseqGroupBox->setChecked(true);
   else if (appName == "notseq") ExcludeSequencesGroupBox->setChecked(true);
   else if (appName == "extractseq") ExtractseqGroupBox->setChecked(true);
   else if (appName == "extractalign") ExtractalignGroupBox->setChecked(true);
   else if (appName == "maskseq") MaskRegionGroupBox->setChecked(true);
   else if (appName == "revseq") ReverseComplementGroupBox->setChecked(true);
   else if (appName == "shuffleseq") ShuffleSequenceGroupBox->setChecked(true);
   else if (appName == "descseq") DescseqGroupBox->setChecked(true);
   else if (appName == "biosed") BiosedGroupBox->setChecked(true);
   else if (appName == "maskambignuc") MaskAmbiguityCaractersNGroupBox->setChecked(true);
   else if (appName == "maskambigprot") MaskAmbiguityCaractersPGroupBox->setChecked(true);
   else if (appName == "sizeseq") SortBySizeGroupBox->setChecked(true);

   disconnect(OutseqAssociatedQualifiersPushButton, SIGNAL(clicked()),nullptr,nullptr);
   if (appName == "pasteseq") {
      connect(OutseqAssociatedQualifiersPushButton, SIGNAL(clicked()), this, SLOT(outseqAssociatedQualifiersPushButton2_clicked()));
      InputFileLineEdit->setToolTip("asequence");
   } else if (appName == "notseq") {
      connect(OutseqAssociatedQualifiersPushButton, SIGNAL(clicked()), this, SLOT(outseqAssociatedQualifiersPushButton2_clicked()));
      InputFileLineEdit->setToolTip("sequence");
   } else if (appName == "sizeseq") {
      InputFileLineEdit->setToolTip("sequences");
      connect(OutseqAssociatedQualifiersPushButton, SIGNAL(clicked()), this, SLOT(openOsAQForm()));
   } else {
      connect(OutseqAssociatedQualifiersPushButton, SIGNAL(clicked()), this, SLOT(openOsAQForm()));
      InputFileLineEdit->setToolTip("sequence");
   }
   runEmbossApp->setEmbossApp(appName);
}

void kmodifyseq::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(SequenceToInsertLineEdit->text());
    runEmbossApp->addEmbossOutputFile(WriteExcludedSequencesToLineEdit->text());
}

void kmsbar::beforeRunningProgram()
{
   QString num;
   num.setNum(PerformPointMutationsComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-point="+num);
   num.setNum(PerformCodonMutationsComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-codon="+num);
   num.setNum(PerformBlockMutationsComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-block="+num);
   runEmbossApp->addEmbossInputFile(DoNotMatchLineEdit->text());
}

void kmwfilter::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void knewseq::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-type="+SequenceTypeComboBox->currentText().left(1));
}

void kno::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   TargetSystemLabel->setEnabled(false);
   TargetSystemComboBox->setEnabled(false);
   RemoveLabel->setEnabled(false);
   RemoveComboBox->setEnabled(false);
   if (text == "noreturn") {
      TargetSystemLabel->setEnabled(true);
      TargetSystemComboBox->setEnabled(true);
   } else if (text == "nospace") {
      RemoveLabel->setEnabled(true);
      RemoveComboBox->setEnabled(true);
   }
   runEmbossApp->setEmbossApp(text);
}

void koctanol::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void koddcomp::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void konto::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   runEmbossApp->setEmbossApp(text);
   if (text == "ontoget" || text == "ontocount" || text == "ontoisobsolete" || text == "ontotext") {
      SubclassesCheckBox->setEnabled(true);
      ObsoleteCheckBox->setEnabled(true);
   } else if (text == "ontogetobsolete") {
      SubclassesCheckBox->setEnabled(true);
      ObsoleteCheckBox->setEnabled(false);
   } else if (text == "ontogetcommon" || text == "ontogetdown" || text == "ontogetroot" || text == "ontogetsibs" || text == "ontogetup") {
      SubclassesCheckBox->setEnabled(false);
      ObsoleteCheckBox->setEnabled(true);
   }
}

kpepdisplay::kpepdisplay(kemboss *parent, const int &program) : kprogramWindow(parent)
{
   setupUi(this);
   postWindowCreated();
   kpwProgramComboBox->setCurrentIndex(program);
}

void kpepdisplay::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool setTo;
   if (text == "wheel") {
      setTo = true;
      runEmbossApp->setEmbossApp("pepwheel");
   } else {
      setTo = false;
      runEmbossApp->setEmbossApp("pepnet");
   }
   StepsLabel->setEnabled(setTo);
   StepsSpinBox->setEnabled(setTo);
   TurnsLabel->setEnabled(setTo);
   TurnsSpinBox->setEnabled(setTo);
   PlotWheelCheckBox->setEnabled(setTo);
}

void kpepinfo::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "graph");
   runEmbossApp->addEmbossInputFile(ChemicalClassesLineEdit->text());
   runEmbossApp->addEmbossInputFile(HydropathyDataLineEdit->text());
}

void kpepwindow::on_SuperimposePlotsCheckBox_stateChanged(int state)
{
   if (state == Qt::Checked) runEmbossApp->setEmbossApp("pepwindowall"); else runEmbossApp->setEmbossApp("pepwindow");
}

void kpepwindow::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void kpolydot::beforeRunningProgram()
{
   if (DumpAllMatchesAsFeatureFilesCheckBox->isChecked()) completeOutputFilename(FeaturesFileLineEdit, "feat");
}

kprettyplot::kprettyplot(kemboss *parent) : kprogramWindow(parent)
{
   setupUi(this);
   loadFormats("colours", BackgroundColorComboBox);
   loadFormats("colours", IdenticalComboBox);
   loadFormats("colours", SimilarComboBox);
   loadFormats("colours", OtherComboBox);
   postWindowCreated();
}

void kprettyplot::beforeRunningProgram()
{
   QString num;
   num.setNum(PluralityDoubleSpinBox->value());
   runEmbossApp->programConfiguration.append("-ratio="+num);
}

void kprettyseq::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
}

void kprimersearch::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kprofit::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void kprophecy::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-type="+TypeComboBox->currentText().left(1));
}

void kprophet::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

kredata::kredata(kemboss *parent) : kprogramWindow(parent)
{
   setupUi(this);
   postWindowCreated();
   EnzymeComboBox->addItems(loadRebaseEnzymes());
}

kremap::kremap(kemboss *parent) : kprogramWindow(parent)
{
   setupUi(this);
   postWindowCreated();
   AvailableEnzymesListWidget->addItems(loadRebaseEnzymes());
}

void kremap::on_AddEnzymePushButton_clicked()
{
   QListWidgetItem *selectedItem = nullptr;
   selectedItem = AvailableEnzymesListWidget->currentItem();
   if (selectedItem != nullptr) EnzymesListWidget->addItem(selectedItem->text());
}

void kremap::on_RemoveEnzymePushButton_clicked()
{
   QListWidgetItem *curItem = EnzymesListWidget->takeItem(EnzymesListWidget->currentRow());
   delete curItem;
}

void kremap::on_SaveEnzymeListAsPushButton_clicked()
{
   saveEnzymeList(EnzymesListWidget);
}

void kremap::beforeRunningProgram()
{
   if (AllEnzymesRadioButton->isChecked())
      runEmbossApp->programConfiguration.append("-enzymes=all");
   else if (SelectFromREBASERadioButton->isChecked())
      runEmbossApp->programConfiguration.append(selectedEnzymes(EnzymesListWidget));
   else if (UseListRadioButton->isChecked()) {
      runEmbossApp->programConfiguration.append("-enzymes=@"+UseListLineEdit->text());
      runEmbossApp->addEmbossInputFile(UseListLineEdit->text());
   }

   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->programConfiguration.append("-frame="+FramesComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->addEmbossInputFile(MethylationDataFileLineEdit->text());
}

kremutate::kremutate(kemboss *parent, const int &program) : kprogramWindow(parent)
{
   setupUi(this);
   postWindowCreated();
   AvailableEnzymesListWidget->addItems(loadRebaseEnzymes());
   kpwProgramComboBox->setCurrentIndex(program);
}

void kremutate::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   if (text == "silent") {
      AllMutationsCheckBox->setEnabled(true);
   } else if (text == "recoder") {
      AllMutationsCheckBox->setEnabled(false);
   }
   runEmbossApp->setEmbossApp(text);
}

void kremutate::on_AddEnzymePushButton_clicked()
{
   QListWidgetItem *selectedItem = nullptr;
   selectedItem = AvailableEnzymesListWidget->currentItem();
   if (selectedItem != nullptr) EnzymesListWidget->addItem(selectedItem->text());
}

void kremutate::on_RemoveEnzymePushButton_clicked()
{
   QListWidgetItem *curItem = EnzymesListWidget->takeItem(EnzymesListWidget->currentRow());
   delete curItem;
}

void kremutate::on_SaveEnzymeListAsPushButton_clicked()
{
   saveEnzymeList(EnzymesListWidget);
}

void kremutate::beforeRunningProgram()
{
   if (AllEnzymesRadioButton->isChecked())
      runEmbossApp->programConfiguration.append("-enzymes=all");
   else if (SelectFromREBASERadioButton->isChecked())
      runEmbossApp->programConfiguration.append(selectedEnzymes(EnzymesListWidget));
   else if (UseListRadioButton->isChecked()) {
      runEmbossApp->programConfiguration.append("-enzymes=@"+UseListLineEdit->text());
      runEmbossApp->addEmbossInputFile(UseListLineEdit->text());
   }
}

void krestover::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(AlternativeREDataFileLineEdit->text());
    runEmbossApp->addEmbossInputFile(MethylationDataFileLineEdit->text());
}

krestrict::krestrict(kemboss *parent) : kprogramWindow(parent)
{
   setupUi(this);
   postWindowCreated();
   AvailableEnzymesListWidget->addItems(loadRebaseEnzymes());
}

void krestrict::on_AddEnzymePushButton_clicked()
{
   QListWidgetItem *selectedItem = nullptr;
   selectedItem = AvailableEnzymesListWidget->currentItem();
   if (selectedItem != nullptr) EnzymesListWidget->addItem(selectedItem->text());
}

void krestrict::on_RemoveEnzymePushButton_clicked()
{
   QListWidgetItem *curItem = EnzymesListWidget->takeItem(EnzymesListWidget->currentRow());
   delete curItem;
}

void krestrict::on_SaveEnzymeListAsPushButton_clicked()
{
   saveEnzymeList(EnzymesListWidget);
}

void krestrict::beforeRunningProgram()
{
   if (AllEnzymesRadioButton->isChecked())
      runEmbossApp->programConfiguration.append("-enzymes=all");
   else if (SelectFromREBASERadioButton->isChecked())
      runEmbossApp->programConfiguration.append(selectedEnzymes(EnzymesListWidget));
   else if (UseListRadioButton->isChecked()) {
      runEmbossApp->programConfiguration.append("-enzymes=@"+UseListLineEdit->text());
      runEmbossApp->addEmbossInputFile(UseListLineEdit->text());
   }
   runEmbossApp->addEmbossInputFile(AlternativeREDataFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(MethylationDataFileLineEdit->text());
}

void kseq::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   UseFeatureInformationCheckBox->setEnabled(true);
   ReadOnlyOneSequenceCheckBox->setEnabled(false);
   if (text == "skipseq") {
      NumberLabel->setEnabled(true);
      NumberSpinBox->setEnabled(true);
      NumberSpinBox->setToolTip("skip");
   } else if (text == "nthseq") {
      NumberLabel->setEnabled(true);
      NumberSpinBox->setEnabled(true);
      NumberSpinBox->setToolTip("number");
      UseFeatureInformationCheckBox->setEnabled(false);
   } else if (text == "nthseqset") {
      NumberLabel->setEnabled(true);
      NumberSpinBox->setEnabled(true);
      NumberSpinBox->setToolTip("number");
   } else if (text == "seqretsetall" || text == "splitsource") {
      NumberLabel->setEnabled(false);
      NumberSpinBox->setEnabled(false);
   } else {
      NumberLabel->setEnabled(false);
      NumberSpinBox->setEnabled(false);
      ReadOnlyOneSequenceCheckBox->setEnabled(true);
   }
   if (text == "entret") {
      OutputFileLineEdit->setToolTip("outfile");
      UseFeatureInformationCheckBox->setEnabled(false);
   } else {
      OutputFileLineEdit->setToolTip("outseq");
   }
   if (text == "splitsource") {
      UseFeatureInformationCheckBox->setText("Retain feature information");
   } else {
      UseFeatureInformationCheckBox->setText("Use feature information");
   }
   runEmbossApp->setEmbossApp(text);
}

void kshowalign::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-show="+ShowComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-order="+OutputOrderComboBox->currentText().left(1));
   if (UpperCaseDoubleSpinBox->value()!=-1) {
      QString num;
      num.setNum(UpperCaseDoubleSpinBox->value());
      runEmbossApp->programConfiguration.append("-setcase="+num);
   }
}

void kshowfeat::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-sort="+SortByComboBox->currentText().section(" ", 0, 0));
}

void kshoworf::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
   QString frames = "";
   if (CheckBox1->isChecked()) frames+="1,";
   if (CheckBox2->isChecked()) frames+="2,";
   if (CheckBox3->isChecked()) frames+="3,";
   if (CheckBox4->isChecked()) frames+="4,";
   if (CheckBox5->isChecked()) frames+="5,";
   if (CheckBox6->isChecked()) frames+="6,";
   frames.chop(1);
   runEmbossApp->programConfiguration.append("-frames="+frames);
}

void kshowpep::beforeRunningProgram()
{
   QString num;
   num.setNum(OutputFormatComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-format="+num);
}

kshowseq::kshowseq(kemboss *parent) : kprogramWindow(parent)
{
   setupUi(this);
   postWindowCreated();
   AvailableEnzymesListWidget->addItems(loadRebaseEnzymes());
}

void kshowseq::on_AddEnzymePushButton_clicked()
{
   QListWidgetItem *selectedItem = nullptr;
   selectedItem = AvailableEnzymesListWidget->currentItem();
   if (selectedItem != nullptr) EnzymesListWidget->addItem(selectedItem->text());
}

void kshowseq::on_RemoveEnzymePushButton_clicked()
{
   QListWidgetItem *curItem = EnzymesListWidget->takeItem(EnzymesListWidget->currentRow());
   delete curItem;
}

void kshowseq::on_SaveEnzymeListAsPushButton_clicked()
{
   saveEnzymeList(EnzymesListWidget);
}

void kshowseq::beforeRunningProgram()
{
   QString num;
   num.setNum(OutputFormatComboBox->currentIndex());
   runEmbossApp->programConfiguration.append("-format="+num);
   if (AllEnzymesRadioButton->isChecked())
      runEmbossApp->programConfiguration.append("-enzymes=all");
   else if (SelectFromREBASERadioButton->isChecked())
      runEmbossApp->programConfiguration.append(selectedEnzymes(EnzymesListWidget));
   else if (UseListRadioButton->isChecked()) {
      runEmbossApp->programConfiguration.append("-enzymes=@"+UseListLineEdit->text());
      runEmbossApp->addEmbossInputFile(UseListLineEdit->text());
   }
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
   num.setNum(SenseComboBox->currentIndex()-1);
   runEmbossApp->programConfiguration.append("-sensematch="+num);
   runEmbossApp->addEmbossInputFile(MethylationDataFileLineEdit->text());
}

void ksirna::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "seq");
}

void ksixpack::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
   completeOutputFilename(OutputFileLineEdit2, "translation");
}

void kskipredundant::on_ModeComboBox_currentIndexChanged(int value)
{
   bool boolean;
   if (value == 0) 
      boolean = false;
   else 
      boolean = true;
   ThresholdLabel->setEnabled(!boolean);
   ThresholdDoubleSpinBox->setEnabled(!boolean);
   MinThresholdLabel->setEnabled(boolean);
   MinThresholdDoubleSpinBox->setEnabled(boolean);
   MaxThresholdLabel->setEnabled(boolean);
   MaxThresholdDoubleSpinBox->setEnabled(boolean);
}

void kskipredundant::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "seq");
   QString num;
   num.setNum(ModeComboBox->currentIndex()+1);
   runEmbossApp->programConfiguration.append("-mode="+num);
}

void kstssearch::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void ksyco::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-cfile="+CodonUsageFileComboBox->currentText().section(" ", 0, 0));
   if (CreateGraphGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "graph");
}

void ktax::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   runEmbossApp->setEmbossApp(text);
   if (text == "taxgetrank") {
      RankGroupBox->setEnabled(true);
      HiddenCheckBox->setEnabled(true);
   } else if (text == "taxgetup") {
      RankGroupBox->setEnabled(false);
      HiddenCheckBox->setEnabled(true);
   } else {
      RankGroupBox->setEnabled(false);
      HiddenCheckBox->setEnabled(false);
   }
}

void ktax::beforeRunningProgram()
{
   if (RankGroupBox->isEnabled()) {
      QString rank = "";
      if (KingdomCheckBox->isChecked()) rank+="kingdom,";
      if (PhylumCheckBox->isChecked()) rank+="phylum,";
      if (ClassCheckBox->isChecked()) rank+="class,";
      if (OrderCheckBox->isChecked()) rank+="order,";
      if (FamilyCheckBox->isChecked()) rank+="family,";
      if (GenusCheckBox->isChecked()) rank+="genus,";
      if (SpeciesCheckBox->isChecked()) rank+="species,";
      if (TribeCheckBox->isChecked()) rank+="tribe,";
      if (VarietasCheckBox->isChecked()) rank+="varietas,";
      if (SpeciesGroupCheckBox->isChecked()) rank+="species group,";
      if (SpeciesSubgroupCheckBox->isChecked()) rank+="species subgroup,";
      if (NoneCheckBox->isChecked()) rank+="no rank,";
      if (SuperkingdomCheckBox->isChecked()) rank+="superkingdom,";
      if (SuperphylumCheckBox->isChecked()) rank+="superphylum,";
      if (SuperclassCheckBox->isChecked()) rank+="superclass,";
      if (SuperorderCheckBox->isChecked()) rank+="superorder,";
      if (SuperfamilyCheckBox->isChecked()) rank+="superfamily,";
      if (SubkingdomCheckBox->isChecked()) rank+="subkingdom,";
      if (SubphylumCheckBox->isChecked()) rank+="subphylum,";
      if (SubclassCheckBox->isChecked()) rank+="subclass,";
      if (SuborderCheckBox->isChecked()) rank+="suborder,";
      if (SubfamilyCheckBox->isChecked()) rank+="subfamily,";
      if (SubgenusCheckBox->isChecked()) rank+="subgenus,";
      if (SubspeciesCheckBox->isChecked()) rank+="subspecies,";
      if (SubtribeCheckBox->isChecked()) rank+="subtribe,";
      if (InfraclassCheckBox->isChecked()) rank+="infraclass,";
      if (InfraorderCheckBox->isChecked()) rank+="infraorder,";
      if (ParvorderCheckBox->isChecked()) rank+="parvorder,";
      rank.chop(1);
      runEmbossApp->programConfiguration.append("-rank="+rank);
   }
}

void ktcode::beforeRunningProgram()
{
   if (CreateGraphCheckBox->isChecked()) completeOutputFilename(GraphOutputFileLineEdit, "graph");
   runEmbossApp->addEmbossInputFile(DataFileLineEdit->text());
}

void ktfscan::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-menu="+ClassComboBox->currentText().left(1));
   runEmbossApp->addEmbossInputFile(CustomDataFileLineEdit->text());
}

void ktmap::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "graph");
}

void ktranalign::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void ktranseq::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-table="+GeneticCodeComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->programConfiguration.append("-frame="+FramesComboBox->currentText().section(" ", 0, 0));
}

void ktwofeat::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-asense="+SenseComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->programConfiguration.append("-bsense="+SenseComboBox_2->currentText().section(" ", 0, 0));
   runEmbossApp->programConfiguration.append("-overlap="+OverlapComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->programConfiguration.append("-rangetype="+TypeOfRangeComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->programConfiguration.append("-sense="+SenseComboBox_3->currentText().left(1));
   runEmbossApp->programConfiguration.append("-order="+OrderComboBox->currentText().section(" ", 0, 0));
}

void kunion::beforeRunningProgram()
{
    if (LookForOverlapsWhenJoiningGroupBox->isChecked()) completeOutputFilename(SequenceOverlapsOutputFileLineEdit, "union");
}

void kvectorstrip::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "seq");
   runEmbossApp->addEmbossInputFile(SelectVectorFileLineEdit->text());
}

void kwobble::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "graph");
}

void kwordfinder::beforeRunningProgram()
{
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossOutputFile(ErrorfileLineEdit->text());
}

void kwordmatch::beforeRunningProgram()
{
   completeOutputFilename(OutputFileLineEdit2, "feat_a");
   completeOutputFilename(OutputFileLineEdit3, "feat_b");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossOutputFile(LogfileLineEdit->text());
}
