/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2020 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef RUNEMBOSSAPP_H
#define RUNEMBOSSAPP_H

#include <QElapsedTimer>
#include <QPointer>

#include "programProgress.h"

class krunEmbossApp : public QObject
// krunEmbossApp is the abstract base class of the classes krunEmbossAppLocal and krunEmbossAppOnServer
{
   Q_OBJECT

public:
    krunEmbossApp(QWidget *parent = nullptr, kembossSettings *fksettings = nullptr);
    virtual ~krunEmbossApp() {}
    void setEmbossApp(const QString &appName) { if (!appName.isEmpty()) cembossApp = appName; }
    void setShowProgressWindow(const bool create) { cShowProgressWindow = create; }
    QString embossApp() { return cembossApp; }
    void addConfigParam(const QString &param) { if (!param.isEmpty()) programConfiguration.append(param); }
    QString programOutput() { return QString(cprogramOutput); }
    virtual bool runApp();
    void addEmbossInputFile(const QString &file) { if (!file.isEmpty()) cembossInputFiles.append(file); }
    void addEmbossOutputFile(const QString &file) { if (!file.isEmpty()) cembossOutputFiles.append(file); }
    void clearEmbossInputFileList() { cembossInputFiles.clear(); }
    void clearEmbossOutputFileList() { cembossOutputFiles.clear(); }
    QStringList programConfiguration;
    QPointer<programProgressForm> programProgress;

signals:
    void applicationExecuted(int exitCode);

protected slots:
    virtual void updateProgramProgressForm();
    virtual void processFinished(int exitCode);
    virtual void killProcess();

protected:
    QPointer<QWidget> parentWindow;
    QPointer<kembossSettings> ksettings;
    QStringList cembossInputFiles;
    // Contains the EMBOSS input files including the paths
    QStringList cembossOutputFiles;
    // Contains the EMBOSS output files including the paths
    QByteArray cprogramOutput;
    // Contains the output of the EMBOSS program on stdout

private:
    QElapsedTimer runTime;
    QString cembossApp;
    bool cShowProgressWindow;
};

#endif // RUNEMBOSSAPP_H
